import { Discussions, DiscussionFilter, Discussion } from "./types";
import { FlarumApi } from "./flarum";
export declare class FlarumDiscussions {
    /**
     * @description Returns Flarum Discussions endpoint with the applied parameters
     */
    static apiUrl: (api: FlarumApi, discussionsFilter?: DiscussionFilter) => string;
    /**
     * @description get all discussions (sort is -time by default)
     * @param userNameOrUserId if authorizing with api key, pass the user ID, otherwise pass the username
     * @param passwordOrApiToken if authorizing with the api key, pass api key, otherwise pass the password.
     * @returns string for error and undefined in case of success
     */
    static getAll: (api: FlarumApi, discussionsFilter?: DiscussionFilter) => Promise<string | Discussions>;
    static getNext: (discussions: Discussions) => Promise<string | Discussions>;
    static getPrev: (discussions: Discussions) => Promise<string | Discussions>;
    static getAllByUrl: (url: string) => Promise<string | Discussions>;
    /**
     * Create a new discussion
     * POST /api/discussions
     * @param api
     * @param discussion
     */
    static create: (api: FlarumApi, discussion: Discussion) => Promise<string | Discussion>;
    /**
     * @description Get information about the forum, including groups and tags
     */
    static get: (api: FlarumApi, id: number) => Promise<string | Discussion>;
    /**
     * PATCH /api/discussions/:id - update the discussion
     * @param api
     * @param id
     * @returns
     */
    static update: (api: FlarumApi, id: number, data: Discussion) => Promise<string | undefined>;
    /**
     * @description Update forum config
     */
    static delete: (api: FlarumApi, id: number) => Promise<undefined | string>;
}
