import { Forum, CreateSessionToken } from "./types";
export type AuthorizeRequest = {
    identification: string;
    password: string;
};
export type AuthorizeReply = {
    token: string;
    userId: string;
};
export declare const generateApiToken: (userId: string) => void;
export declare class FlarumApi {
    readonly endpoint: string;
    private token;
    private userId;
    readonly verbose: boolean;
    /**
     *
     * @param endpoint Your forum's API endpoint. It ends with 'api'
     * @param token Your API Key. Use generateApiToken function.
     * @param verbose Optionally, if set, it will print the progress. For debug only
     */
    constructor(endpoint: string, verbose?: boolean);
    /**
     * Creates a new FlarumApi authorized with the given token.
     * @param token
     * @returns FlarumApi
     */
    cloneWithToken: (token: string, userId?: number) => FlarumApi;
    /**
     * @description Authorize the Client to access the Flarum Endpoint.
     * Without authorization, Most of the POST/PUT/DELETE operations are not available.
     *
     * Flarum supports two way of authentication, either through API Keys.
     * Or through the Access Tokens.
     * @param userNameOrUserId if authorizing with api key, pass the user ID, otherwise pass the username
     * @param passwordOrApiToken if authorizing with the api key, pass api key, otherwise pass the password.
     * @returns string for error and undefined in case of success
     */
    authorize: (userNameOrUserId: string | number, passwordOrApiToken: string) => Promise<CreateSessionToken | string>;
    /**
     * @description Get information about the forum, including groups and tags
     */
    get: () => Promise<string | Forum>;
    /**
     * @description Update forum config
     */
    update: () => Promise<undefined>;
    /**
     * @description fetch the data through authentication
     */
    getFetch: (url: string) => Promise<string | any>;
    postFetch: (url: string, body: string) => Promise<string | any>;
}
